/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import classNames from "classnames";
import React from "react";
import { Divider, Responsive } from "semantic-ui-react";
import { GenericIcon } from "../icon";
import { Heading } from "../typography";
/**
 * Component to showcase key marketing messages.
 *
 * @param {JumbotronPropsInterface} props - Props injected to the components.
 *
 * @return {React.ReactElement}
 */
export const Jumbotron = (props) => {
    const { className, content, bordered, clearing, heading, headingAs, icon, iconOptions, iconSize, subHeading, subHeadingAs, padded, textAlign, ["data-testid"]: testId } = props;
    const classes = classNames("ui-jumbotron", {
        [typeof bordered === "boolean" ? "bordered-default" : `bordered-${bordered}`]: bordered,
        clearing,
        padded,
        [`text-${textAlign}`]: textAlign
    }, className);
    return (React.createElement("div", { className: classes },
        (heading || subHeading) && (React.createElement("div", { className: "jumbotron-content-wrapper inline" },
            heading && (React.createElement(Heading, { className: "jumbotron-heading inline ellipsis", as: headingAs, "data-testid": `${testId}-heading`, compact: true }, heading)),
            subHeading && (React.createElement(Heading, { className: "jumbotron-sub-heading", "data-testid": `${testId}-sub-heading`, as: subHeadingAs, subHeading: true, ellipsis: true }, subHeading)))),
        content && (React.createElement(React.Fragment, null,
            React.createElement(Divider, null),
            content)),
        icon && (React.createElement(Responsive, Object.assign({ as: GenericIcon, icon: icon, size: iconSize, floated: "right", transparent: true, minWidth: Responsive.onlyComputer.minWidth }, iconOptions)))));
};
/**
 * Default props for the stat count card.
 */
Jumbotron.defaultProps = {
    bordered: "bottom",
    clearing: true,
    "data-testid": "jumbotron",
    headingAs: "h1",
    iconSize: "auto",
    padded: true,
    subHeadingAs: "h5",
    textAlign: "left"
};
//# sourceMappingURL=jumbotron.js.map